from pathlib import Path
import os
import glob
from PIL import Image, ImageDraw

###################################################################################################
# brief:
    # Turns a directory of images into a gif.
# params (see default values for examples):
    # source_dir - The source directory of the images to turn into a gif. Must include preceding ./
    # out_dir    - The directory to save the gif to. Must include preceding ./
    # gif_name   - The name of the gif. Do not include filetype.
    # duration   - Number of frames in the gif...I think.
    # file_type  - File extension for the images. Do not include preceding .
# example call:
    # MakeGif('./data', './', 'test', 100, 'jpg')
###################################################################################################

def MakeGif(source_dir='./', out_dir='./', gif_name='test', duration=100, file_type='jpg'):
    '''brief:
            Turns a directory of images into a gif.
        params (see default values for examples):
            source_dir - The source directory of the images to turn into a gif. Must include preceding ./
            out_dir    - The directory to save the gif to. Must include preceding ./
            gif_name   - The name of the gif. Do not include filetype.
            duration   - Number of frames in the gif...I think.
            file_type  - File extension for the images. Do not include preceding .
        example call:
            MakeGif('./data', './', 'test', 100, 'jpg')'''
    images = []
    
    paths = sorted(Path(source_dir).iterdir(), key=os.path.getmtime)
    
    for file in paths:
        if str(file).endswith('.' + file_type):
            images.append(Image.open(file))

    if(len(images) > 0):
        images[0].save(out_dir + '/' + gif_name + '.gif', save_all=True, append_images=images[1:], optimize=False, duration=100, loop=0)


import pandas as pd

###################################################################################################
# brief:
    # Displays in depth analysis of the correlation between features. Currently only addresses
    # correlation of dependent feature to independent features, but will be updated soon.
# params (see default values for examples):
    # df          - The dataframe to analyze.
    # dep_feature - The dependent feature.
# example call:
    # df = pd.read_csv('Iris.csv')
    # CorrMatrixAnalysis(df, 'species')
###################################################################################################
def CorrMatrixAnalysis(df, dep_feature):
    '''brief:
            Displays in depth analysis of the correlation between features. Currently only addresses
            correlation of dependent feature to independent features, but will be updated soon.
        params (see default values for examples):
            df          - The dataframe to analyze.
            dep_feature - The dependent feature
        example call:
            df = pd.read_csv('Iris.csv')
            CorrMatrixAnalysis(df, 'species')'''
    dep_feature = str(dep_feature)
    corr = df.corr()
    dep, corrs = corr[dep_feature], []
    dep_t = dep.drop(dep_feature).abs().sort_values(ascending=False).dropna()
    corrs.append(['High', dep_t.loc[dep_t >= 0.7]])
    corrs.append(['Moderate', dep_t.loc[(dep_t >= 0.5) & (dep_t < 0.7)]])
    corrs.append(['Low', dep_t.loc[(dep_t >= 0.3) & (dep_t < 0.5)]])
    corrs.append(['No', dep_t.loc[dep_t < 0.3]])
    for corr_ in corrs:
        if corr_[1].size > 0:
            print("Features With " + corr_[0] + " Correlation to " + dep_feature + ":")
            [print("% .2f  -" % round(dep[x],2), x) for x in corr_[1].index]
            print('\n')


#-------------------------------------------------------------------------------------
import glob
import os
from pathlib import Path

def ClearDir(path='./'):
    '''brief:
            Removes all files from a directory.
        params (see default values for examples):
            path - The source directory of the images to turn into a gif. 
                   Must include preceding ./, should not include ending /
        example call:
            ClearDir('./kmeans/images')'''
    print("Delete files from " + path + " y/n?")
    if(input() == 'y'):
        files = glob.glob(path + '/*')
        for f in files:
            os.remove(f)

#-------------------------------------------------------------------------------------
import time
from IPython.display import Audio, display
def play_sound(self, etype, value, tb, tb_offset=None):
    display(Audio(url='https://www.redringtones.com/wp-content/uploads/2016/09/R2D2-scream.mp3', autoplay=True))
    time.sleep(0.25)
    self.showtraceback((etype, value, tb), tb_offset=tb_offset)
def ActivateCellFailSound():
    '''brief:
            Plays a ding if the cell execution fails. Only works for Jupyter Notebook.
        example call:
            CellFailChime()'''
    get_ipython().set_custom_exc((Exception,), play_sound)

#-------------------------------------------------------------------------------------
from IPython.display import Audio, display
class VarPrinter:
     def __init__(self, ip, url):
         self.ip = ip
         self.url_ = url
     def post_run_cell(self, result):
        if result.error_in_exec != None:
            print('womp womp')
        else:
            display(Audio(url=self.url_, autoplay=True))
            time.sleep(0.5)
def load_ipython_extension(ip, url):
    vp = VarPrinter(ip, url)
    ip.events.register("post_run_cell", vp.post_run_cell)

def ActivateCellDoneSound(url='http://soundfxcenter.com/movies/star-wars/8d82b5_Star_Wars_R2-D2_Excited_Sound_Effect.mp3'):
    '''brief:
          Plays a ding when a cell is complete. Kind of buggy with a failed cell.
        example call:
            CellDoneChime()'''
    load_ipython_extension(get_ipython(),url)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="bae0n-utils",
    version="0.0.18",
    author="Aeon Williams",
    author_email="aeonwilliams@gmail.com",
    description="Utility functions to be used in Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/aeonwilliams/bae0n_utils/blob/main/README.md",
    packages=setuptools.find_packages(),
    install_requires=[
        'Pillow', 'numpy', 'pandas', 'pathlib'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3',
)